function H = fr2bandmeyer(omega,ep)

%function H = fr2bandmeyer(omega,ep)
%
%Generation of Meyer 2 band filters (frequential)
%INPUT:
%   omega: pulsations
%   ep: epsilon
%OUTPUT:
%   H: frequential response

%*****************************************************
%* author: Caroline Chaux                            *
%* institution: Institut Gaspard Monge - CNRS	     *
%*	       Universit de Marne la Valle             *
%* date: Thursday, November, 2nd 2006                *
%* License CeCILL-B				      *
%*****************************************************

if ep <0 | ep > 1/3
    error('epsilon should be chosen between 0 and 1/3')
end

H = zeros(2,length(omega));

omega = angle(exp(i*omega));

aomega = abs(omega);

ind = find(aomega<=pi*(1-ep)/2);
H(1,ind) = sqrt(2);
ind = find(aomega>pi*(1-ep)/2 & aomega<pi*(1+ep)/2 );
H(1,ind) = rhomeyer(aomega(ind)-pi*(1-ep)/2,ep,2);

ind = find(aomega>pi*(1-ep)/2 & aomega<pi*(1+ep)/2);
H(2,ind) = rhomeyer(aomega(ind)-pi*(1+ep)/2,ep,2);
ind = find(aomega>=pi*(1+ep)/2);
H(2,ind) = sqrt(2);


H(2,:) = H(2,:).*exp(-1*i*omega);

