function [H,G] = gene_pw(N,typ,rm)
%GENE_PW Obtention des coefficients permettant de generer des 
% ondelettes periodiques.
% [H,G] = GENE_PW(N,TYP,RM) reponses frequentielles des filtres passe-bas
% et passe-haut servant a reconstruire chaque niveau
% de resolution, rangees dans l'ordre de resolution
% decroissante.
% N nombre de donnees
% TYP type d'ondelette
% RM resolution maximale, par defaut NEXTPOW2(N). 

% copyrights : J.-C. Pesquet - H. Krim  
% Thursday, November, 2nd 2006			      

if nargin==2
   rm=nextpow2(N);
elseif nargin~=3
   error('Arguments en nombre incorrect')
end
if strcmp(typ,'haar') | strcmp(typ,'daubechies')
   if strcmp(typ,'haar')
      p = 1;
   else
      p = 2;
   end
   bh = irdaub(p);
%   bg = [1 -1]/sqrt(2);
   H = freqz(bh,1,N,'whole').';
   %H = H.*exp(-j*2*pi*(-p+1)*(0:N-1)/N);
   H = H.*exp(-j*2*pi*(-p)*(0:N-1)/N);
%   G = freqz(bg,1,N,'whole').';
elseif strcmp(typ,'meyer')
   H = frmeyer(N,'exmeyer',1/6);
elseif strcmp(typ,'sinc');
%   H = [ones(1,N/4) zeros(1,N/2) ones(1,N/4)]*sqrt(2);
   H = [ones(1,N/4) zeros(1,N/4+1)]*sqrt(2); 
   H(N/4+1) = 1; 
   H = [H H(N/2:-1:2)];
elseif strcmp(typ,'splis')
   H = frsplis(N,4);
else
   error('Ondelette de type inconnu')
end
G = freqcqf(H);
ind = 1:N;

%disp('avant r ind');
for r=1:rm-1
   %disp('r ind');
   ind = [ind (1:2^r:N)];
end
H = H(ind);
G = G(ind); 
   
        
