function H = gene_pwMbandes(N,M)
%GENE_PWMbandes Obtention des coefficients permettant de generer des 
% ondelettes de Shannon M bandes .

%function H = gene_pwMbandes(N,M)
%
%Generation of Shannon M band filters (frequential)
%INPUT:
%   N: number of points
%   M: number of bands
%OUTPUT:
%   H: frequential responses

%*****************************************************
%* author: Caroline Chaux                            *
%* institution: Institut Gaspard Monge - CNRS	     *
%*	       Universit de Marne la Valle             *
%* date: Thursday, November, 2nd 2006                *
%* License CeCILL-B				      *
%*****************************************************


if rem(N,M)~=0 || rem(N,2)~=0
    error('N doit tre un multiple de 2*M');
end

%low-pass
H(1,1:N/2+1) = [ones(1,N/(2*M)) zeros(1,N/2+1-N/(2*M))]*sqrt(M);
H(1,(N/(2*M)+1)) = sqrt(M/2);
H(1,1:N) = [H(1,1:N/2+1) H(1,N/2:-1:2)];

%band-pass
for m=2:M-1
    H(m,1:N/2+1) = [ zeros(1,(m-1)*N/(2*M)) ones(1,N/(2*M)) zeros(1,N/2+1-(m-1)*N/(2*M)-N/(2*M))]*sqrt(M);
    H(m,((m-1)*N/(2*M)+1)) = sqrt(M/2);
    H(m,((m-1)*N/(2*M)+N/(2*M)+1)) = sqrt(M/2);
    %H(m,((m-1)*N/(2*M)+2*N/(2*M)+1)) = sqrt(M/2);
    H(m,1:N) = [H(m,1:N/2+1) H(m,N/2:-1:2)];
end

%high-pass
H(M,1:N/2+1) = [ zeros(1,(M-1)*N/(2*M)) ones(1,N/(2*M)) zeros(1,N/2+1-(M-1)*N/(2*M)-N/(2*M))]*sqrt(M);
H(M,((M-1)*N/(2*M)+1)) = sqrt(M/2);
H(M,((M-1)*N/(2*M)+N/(2*M)+1)) = sqrt(M);
H(M,1:N) = [H(M,1:N/2+1) H(M,N/2:-1:2)];
